﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Interop;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace FlexGrid.Ink.Input
{
    /// <summary>
    /// Interaction logic for InkContainer.xaml
    /// </summary>
    public partial class InkInputDialog : Window
    {
        public StrokeCollection Strokes { get; private set; }
        public InkInputDialog()
        {
            InitializeComponent();
            this.Loaded += InkInputDialog_Loaded;
        }

        private void InkInputDialog_Loaded(object sender, RoutedEventArgs e)
        {
            this.HideMinimizeAndMximizeButtons();
        }

        private void Mode_Click(object sender, RoutedEventArgs e)
        {
            inkCanvas.EditingMode = inkCanvas.EditingMode == InkCanvasEditingMode.Ink ? InkCanvasEditingMode.EraseByStroke : InkCanvasEditingMode.Ink;
        }

        private void C1ColorPicker_SelectedColorChanged(object sender, C1.WPF.PropertyChangedEventArgs<Color> e)
        {
            strokeColor.Color = e.NewValue;
        }

        private void SaveInk_Click(object sender, RoutedEventArgs e)
        {
            Strokes = inkCanvas.Strokes;
            DialogResult = true;
        }
    }
    public class EditModeToImageConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            var editMode = (InkCanvasEditingMode)value;
            switch (editMode)
            {
                case InkCanvasEditingMode.EraseByPoint:
                case InkCanvasEditingMode.EraseByStroke:
                    return new Image() { Source = new BitmapImage(new Uri("pack://siteoforigin:,,,/Resources/pencil.png")) };
                case InkCanvasEditingMode.Ink:
                    return new Image() { Source = new BitmapImage(new Uri("pack://siteoforigin:,,,/Resources/eraser.png")) };
            }
            return null;
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
    internal static class WindowExtensions
    {
        private const int GWL_STYLE = -16, WS_MAXIMIZEBOX = 0x10000, WS_MINIMIZEBOX = 0x20000;

        [DllImport("user32.dll")]
        extern private static int GetWindowLong(IntPtr hwnd, int index);
        [DllImport("user32.dll")]
        extern private static int SetWindowLong(IntPtr hwnd, int index, int value);

        internal static void HideMinimizeAndMximizeButtons(this Window window)
        {
            IntPtr hwnd = new WindowInteropHelper(window).Handle;
            var currentStyle = GetWindowLong(hwnd, GWL_STYLE);

            SetWindowLong(hwnd, GWL_STYLE, currentStyle & ~WS_MAXIMIZEBOX & ~WS_MINIMIZEBOX);
        }
    }
}
